summaryrefslogtreecommitdiffstats
path: root/certmanager/conf/appearanceconfigpage.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'certmanager/conf/appearanceconfigpage.cpp')
-rw-r--r--certmanager/conf/appearanceconfigpage.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/certmanager/conf/appearanceconfigpage.cpp b/certmanager/conf/appearanceconfigpage.cpp
index 9e5d0f74..53030bbd 100644
--- a/certmanager/conf/appearanceconfigpage.cpp
+++ b/certmanager/conf/appearanceconfigpage.cpp
@@ -39,7 +39,7 @@
#include <tdepimmacros.h>
AppearanceConfigurationPage::AppearanceConfigurationPage( TQWidget * parent, const char * name )
- : KCModule( parent, name )
+ : TDECModule( parent, name )
{
TQVBoxLayout* lay = new TQVBoxLayout( this );
mWidget = new Kleo::AppearanceConfigWidget( this );
@@ -70,7 +70,7 @@ void AppearanceConfigurationPage::defaults()
extern "C"
{
- KDE_EXPORT KCModule *create_kleopatra_config_appear( TQWidget *parent, const char * )
+ KDE_EXPORT TDECModule *create_kleopatra_config_appear( TQWidget *parent, const char * )
{
AppearanceConfigurationPage *page =
new AppearanceConfigurationPage( parent, "kleopatra_config_appear" );
@@ -78,7 +78,7 @@ extern "C"
}
}
// tdelibs-3.2 didn't have the changed signal in KCModule...
void AppearanceConfigurationPage::slotChanged()
{
emit changed(true);
@@ -78,7 +78,7 @@ extern "C"
}
}
-// tdelibs-3.2 didn't have the changed signal in KCModule...
+// tdelibs-3.2 didn't have the changed signal in TDECModule...
void AppearanceConfigurationPage::slotChanged()
{